@@ -443,7 +443,7 @@ def binom_var_test_df(c1, c2, sym=False, max_m=-1, singleton=True) :
         n1 = df_hist[(df_hist.n1 == 1) & (df_hist.n2 == 0)].N.values
         n2 = df_hist[(df_hist.n1 == 0) & (df_hist.n2 == 1)].N.values
         if len(n1) + len(n2) >= 2 :
-            df_hist.loc[df_hist.m == 1,'pval'] = binom_test_two_sided(n1, n1 + n2 , 1/2)
+            df_hist.loc[df_hist.m == 1,'pval'] = binom_test_two_sided(n1, n1 + n2 , 1/2).squeeze()
 
     return df_hist
 
